@@ -97,7 +97,7 @@ pub(super) fn draw_base<T: fmt::Write>(
         scalex,
         scaley,
         preserve_aspect,
-        aspect_offset
+        aspect_offset,
     } = sd;
 
     writer
@@ -147,11 +147,7 @@ pub(super) fn draw_base<T: fmt::Write>(
         //Draw step lines
         //https://stackoverflow.com/questions/60497397/how-do-you-format-a-float-to-the-first-significant-decimal-and-with-specified-pr
 
-        let ideal_num_xsteps=if preserve_aspect{
-            5
-        }else{
-            9
-        };
+        let ideal_num_xsteps = if preserve_aspect { 5 } else { 9 };
 
         let ideal_num_ysteps = 7;
 
@@ -175,7 +171,7 @@ pub(super) fn draw_base<T: fmt::Write>(
                     || good_normalized_step == 5
                     || good_normalized_step == 10
             );
-            
+
             if good_normalized_step == 10 {
                 good_normalized_step = 5;
             }
@@ -238,8 +234,8 @@ pub(super) fn draw_base<T: fmt::Write>(
                 writer.single("line", |d| {
                     d.attr("class", "poloto_axis_lines")
                         .attr("stroke", "black")
-                        .attr("x1", aspect_offset+xx)
-                        .attr("x2", aspect_offset+xx)
+                        .attr("x1", aspect_offset + xx)
+                        .attr("x2", aspect_offset + xx)
                         .attr("y1", height - paddingy)
                         .attr("y2", height - paddingy * 0.95);
                 });
@@ -249,7 +245,7 @@ pub(super) fn draw_base<T: fmt::Write>(
                         d.attr("class", "poloto_text")
                             .attr("alignment-baseline", "start")
                             .attr("text-anchor", "middle")
-                            .attr("x", aspect_offset+xx)
+                            .attr("x", aspect_offset + xx)
                             .attr("y", height - paddingy + texty_padding);
                     })
                     .build(|w| {
@@ -298,8 +294,8 @@ pub(super) fn draw_base<T: fmt::Write>(
                 writer.single("line", |d| {
                     d.attr("class", "poloto_axis_lines")
                         .attr("stroke", "black")
-                        .attr("x1", aspect_offset+padding)
-                        .attr("x2", aspect_offset+padding * 0.96)
+                        .attr("x1", aspect_offset + padding)
+                        .attr("x2", aspect_offset + padding * 0.96)
                         .attr("y1", yy)
                         .attr("y2", yy);
                 });
@@ -309,7 +305,7 @@ pub(super) fn draw_base<T: fmt::Write>(
                         d.attr("class", "poloto_text")
                             .attr("alignment-baseline", "middle")
                             .attr("text-anchor", "end")
-                            .attr("x", aspect_offset+padding - textx_padding)
+                            .attr("x", aspect_offset + padding - textx_padding)
                             .attr("y", yy);
                     })
                     .build(|w| {
@@ -335,11 +331,14 @@ pub(super) fn draw_base<T: fmt::Write>(
                     ),
                 )
                 .path(|p| {
-                    p.put(M(padding+aspect_offset, height - paddingy));
-                    if preserve_aspect{
-                        p.put(L(height-paddingy/2.0 +aspect_offset, height - paddingy));
-                    }else{
-                        p.put(L(width - padding+aspect_offset, height - paddingy));
+                    p.put(M(padding + aspect_offset, height - paddingy));
+                    if preserve_aspect {
+                        p.put(L(
+                            height - paddingy / 2.0 + aspect_offset,
+                            height - paddingy,
+                        ));
+                    } else {
+                        p.put(L(width - padding + aspect_offset, height - paddingy));
                     }
                 });
         });
@@ -357,8 +356,8 @@ pub(super) fn draw_base<T: fmt::Write>(
                     ),
                 )
                 .path(|p| {
-                    p.put(M(aspect_offset+padding, height - paddingy));
-                    p.put(L(aspect_offset+padding, paddingy));
+                    p.put(M(aspect_offset + padding, height - paddingy));
+                    p.put(L(aspect_offset + padding, paddingy));
                 });
         });
     }
